==> apache-doris-2.0.15.1-src.tar.gz: apache-doris-2.0.15.1-src/fe/fe-core/src/main/java/org/apache/doris/nereids/rules/implementation/LogicalJdbcScanToPhysicalJdbcScan.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.rules.implementation;

import org.apache.doris.nereids.rules.Rule;
import org.apache.doris.nereids.rules.RuleType;
import org.apache.doris.nereids.trees.plans.physical.PhysicalJdbcScan;

import java.util.Optional;

/**
 * Implementation rule that convert logical JdbcScan to physical JdbcScan.
 */
public class LogicalJdbcScanToPhysicalJdbcScan extends OneImplementationRuleFactory {
    @Override
    public Rule build() {
        return logicalJdbcScan().then(jdbcScan ->
            new PhysicalJdbcScan(
                jdbcScan.getRelationId(),
                jdbcScan.getTable(),
                jdbcScan.getQualifier(),
                Optional.empty(),
                jdbcScan.getLogicalProperties(),
                jdbcScan.getConjuncts())
        ).toRule(RuleType.LOGICAL_JDBC_SCAN_TO_PHYSICAL_JDBC_SCAN_RULE);
    }
}

==> apache-doris-4.0.0-rc02-src.tar.gz: apache-doris-4.0.0-rc02-src/fe/fe-core/src/main/java/org/apache/doris/nereids/rules/implementation/LogicalJdbcScanToPhysicalJdbcScan.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.rules.implementation;

import org.apache.doris.nereids.rules.Rule;
import org.apache.doris.nereids.rules.RuleType;
import org.apache.doris.nereids.trees.plans.physical.PhysicalJdbcScan;

import java.util.Optional;

/**
 * Implementation rule that convert logical JdbcScan to physical JdbcScan.
 */
public class LogicalJdbcScanToPhysicalJdbcScan extends OneImplementationRuleFactory {
    @Override
    public Rule build() {
        return logicalJdbcScan().then(jdbcScan ->
            new PhysicalJdbcScan(
                jdbcScan.getRelationId(),
                jdbcScan.getTable(),
                jdbcScan.getQualifier(),
                Optional.empty(),
                jdbcScan.getLogicalProperties())
        ).toRule(RuleType.LOGICAL_JDBC_SCAN_TO_PHYSICAL_JDBC_SCAN_RULE);
    }
}
